@@ -142,7 +142,11 @@ def typ_to_slv(typ):
     if isinstance(typ, typs.StdLogic):
         new_typ = typ
     else:
-        new_typ = typs.ConstrainedStdLogicVector(identifier=None, size=typ.size.value())
+        if isinstance(typ.size, int):
+            size=typ.size
+        else:
+            size = typ.size.value()
+        new_typ = typs.ConstrainedStdLogicVector(identifier=None, size=size)
     return new_typ
 
 
